@@ -113,10 +113,9 @@ static void get_property (GObject*, guint prop_id,       GValue*, GParamSpec* );
 /* entries' visibility */
 static GList * get_entries_default               (IndicatorObject*);
 static GList * get_all_entries                   (IndicatorObject*);
-static void entry_being_removed_default          (IndicatorObject*, IndicatorObjectEntry*);
 static void indicator_object_entry_being_removed (IndicatorObject*, IndicatorObjectEntry*);
-static void entry_was_added_default              (IndicatorObject*, IndicatorObjectEntry*);
 static void indicator_object_entry_was_added     (IndicatorObject*, IndicatorObjectEntry*);
+static gint indicator_object_real_get_position   (IndicatorObject*);
 static IndicatorObjectEntryPrivate * entry_get_private (IndicatorObject*, IndicatorObjectEntry*);
 
 G_DEFINE_TYPE (IndicatorObject, indicator_object, G_TYPE_OBJECT);
@@ -141,8 +140,9 @@ indicator_object_class_init (IndicatorObjectClass *klass)
 	klass->get_accessible_desc = NULL;
 	klass->get_entries = get_entries_default;
 	klass->get_location = NULL;
-	klass->entry_being_removed = entry_being_removed_default;
-	klass->entry_was_added = entry_was_added_default;
+	klass->entry_being_removed = NULL;
+	klass->entry_was_added = NULL;
+	klass->get_position = indicator_object_real_get_position;
 
 	klass->entry_activate = NULL;
 	klass->entry_activate_window = NULL;
@@ -780,6 +780,14 @@ indicator_object_entry_was_added (IndicatorObject * io, IndicatorObjectEntry * e
 	}
 }
 
+static gint
+indicator_object_real_get_position (IndicatorObject *io)
+{
+	g_return_val_if_fail (INDICATOR_IS_OBJECT (io), -1);
+
+	return -1;
+}
+
 /**
 	indicator_object_set_environment:
 	@io: #IndicatorObject to set on
@@ -937,61 +945,18 @@ set_property (GObject       * object,
         }
 }
 
-/***
-****
-***/
-
-/* Cloaked entries are ones which are hidden but may be re-added later.
-   They are reffed + unparented so that they'll survive even if the
-   rest of the widgetry is destroyed */
-#define CLOAKED_KEY "entry-is-cloaked"
-
-static void
-decloak_widget (gpointer w)
+gboolean
+indicator_object_entry_is_visible (IndicatorObject * io, IndicatorObjectEntry * entry)
 {
-	if (w != NULL) {
-		GObject * o = G_OBJECT(w);
-		if (g_object_steal_data (o, CLOAKED_KEY) != NULL) {
-			g_object_unref (o);
-		}
-	}
+	g_return_val_if_fail (INDICATOR_IS_OBJECT (io), FALSE);
+
+	return entry_get_private (io, entry)->visibility == ENTRY_VISIBLE;
 }
 
-static void
-entry_was_added_default (IndicatorObject * io, IndicatorObjectEntry * entry)
+gint
+indicator_object_get_position (IndicatorObject *io)
 {
-	decloak_widget (entry->image);
-	decloak_widget (entry->label);
-	decloak_widget (entry->menu);
-}
+	g_return_val_if_fail (INDICATOR_IS_OBJECT (io), FALSE);
 
-static void
-cloak_widget (gpointer w)
-{
-	if (w != NULL) {
-		GtkWidget * parent;
-
-		/* tag this object as cloaked */
-		GObject * o = G_OBJECT(w);
-		g_object_ref (o);
-		g_object_set_data (o, CLOAKED_KEY, GINT_TO_POINTER(1));
-
-		/* remove it from its surrounding widgetry */
-		if(GTK_IS_MENU(w)) {
-			if (gtk_menu_get_attach_widget (GTK_MENU(w)) != NULL) {
-				gtk_menu_detach (GTK_MENU(w));
-			}
-		}
-		else if((parent = gtk_widget_get_parent(w))) {
-			gtk_container_remove(GTK_CONTAINER(parent), w);
-		}
-	}
-}
-
-static void
-entry_being_removed_default (IndicatorObject * io, IndicatorObjectEntry * entry)
-{
-	cloak_widget (entry->image);
-	cloak_widget (entry->label);
-	cloak_widget (entry->menu);
+	return INDICATOR_OBJECT_GET_CLASS (io)->get_position (io);
 }
