@@ -60,6 +60,9 @@ typedef enum
 #define INDICATOR_OBJECT_SIGNAL_SECONDARY_ACTIVATE "secondary-activate"
 #define INDICATOR_OBJECT_SIGNAL_SECONDARY_ACTIVATE_ID (g_signal_lookup(INDICATOR_OBJECT_SIGNAL_SECONDARY_ACTIVATE, INDICATOR_OBJECT_TYPE))
 
+/* the name of the property to decide whether or not entries are visible by default */
+#define INDICATOR_OBJECT_DEFAULT_VISIBILITY        "indicator-object-default-visibility"
+
 typedef struct _IndicatorObject        IndicatorObject;
 typedef struct _IndicatorObjectClass   IndicatorObjectClass;
 typedef struct _IndicatorObjectPrivate IndicatorObjectPrivate;
@@ -91,6 +94,12 @@ typedef struct _IndicatorObjectEntry   IndicatorObjectEntry;
 	@get_show_now: Returns whether the entry is requesting to
 		be shown "right now" in that it has something important
 		to tell the user.
+	@entry_being_removed: Called before an entry is removed.
+		The default implementation is to ref and unparent the
+		entry's widgets so that they can be re-added later.
+	@entry_was_added: Called after an entry is added.
+		The default implementation is to unref the entry's widgets if
+		previously reffed by entry_being_removed's default impementation
 	@entry_activate: Should be called when the menus for a given
 		entry are shown to the user.
 	@entry_close: Called when the menu is closed.
@@ -102,6 +111,7 @@ typedef struct _IndicatorObjectEntry   IndicatorObjectEntry;
 	@show_now_changed: Slot for #IndicatorObject::show-now-changed
 	@accessible_desc_update: Slot for #IndicatorObject::accessible-desc-update
 	@secondary_activate: Slot for #IndicatorObject::secondary-activate
+	@get_position: returns the desired position on the panel (0 is right-most), or -1
 */
 struct _IndicatorObjectClass {
 	GObjectClass parent_class;
@@ -117,7 +127,11 @@ struct _IndicatorObjectClass {
 	guint      (*get_location) (IndicatorObject * io, IndicatorObjectEntry * entry);
 	gboolean   (*get_show_now) (IndicatorObject * io, IndicatorObjectEntry * entry);
 
+	void       (*entry_being_removed) (IndicatorObject * io, IndicatorObjectEntry * entry);
+	void       (*entry_was_added) (IndicatorObject * io, IndicatorObjectEntry * entry);
+
 	void       (*entry_activate) (IndicatorObject * io, IndicatorObjectEntry * entry, guint timestamp);
+	void       (*entry_activate_window) (IndicatorObject * io, IndicatorObjectEntry * entry, guint windowid, guint timestamp);
 	void       (*entry_close) (IndicatorObject * io, IndicatorObjectEntry * entry, guint timestamp);
 
 	/* Signals */
@@ -130,12 +144,13 @@ struct _IndicatorObjectClass {
 	void       (*accessible_desc_update) (IndicatorObject * io, IndicatorObjectEntry * entry, gpointer user_data);
 	void       (*secondary_activate) (IndicatorObject * io, IndicatorObjectEntry * entry, guint timestamp, gpointer user_data);
 
+	gint       (*get_position) (IndicatorObject *io);
+	guint      (*get_parent_window) (IndicatorObject *io);
+
 	/* Reserved */
 	void       (*reserved1)     (void);
 	void       (*reserved2)     (void);
 	void       (*reserved3)     (void);
-	void       (*reserved4)     (void);
-	void       (*reserved5)     (void);
 };
 
 /**
@@ -151,6 +166,7 @@ struct _IndicatorObject {
 
 /**
 	IndicatorObjectEntry:
+	@parent_object: The #IndicatorObject that created this entry
 	@label: The label to be shown on the panel
 	@image: The image to be shown on the panel
 	@menu: The menu to be added to the menubar
@@ -158,23 +174,24 @@ struct _IndicatorObject {
 		of the indicator
 	@name_hint: A name to describe the indicator being placed to allow
 		the caller to be more aware of the individual entries.
+	@parent_window: the id of the parent window of the indicator entry (if any).
 
 	@reserved1: Reserved for future use
 	@reserved2: Reserved for future use
 	@reserved3: Reserved for future use
-	@reserved4: Reserved for future use
 */
 struct _IndicatorObjectEntry {
+	IndicatorObject * parent_object;
 	GtkLabel * label;
 	GtkImage * image;
 	GtkMenu  * menu;
 	const gchar * accessible_desc;
 	const gchar * name_hint;
+	guint parent_window;
 
 	void       (*reserved1)     (void);
 	void       (*reserved2)     (void);
 	void       (*reserved3)     (void);
-	void       (*reserved4)     (void);
 };
 
 GType indicator_object_get_type (void);
@@ -183,11 +200,15 @@ IndicatorObject * indicator_object_new_from_file (const gchar * file);
 GList * indicator_object_get_entries (IndicatorObject * io);
 guint   indicator_object_get_location (IndicatorObject * io, IndicatorObjectEntry * entry);
 guint   indicator_object_get_show_now (IndicatorObject * io, IndicatorObjectEntry * entry);
+void	indicator_object_set_visible (IndicatorObject * io, gboolean visible);
+gboolean indicator_object_entry_is_visible (IndicatorObject * io, IndicatorObjectEntry * entry);
 void    indicator_object_entry_activate (IndicatorObject * io, IndicatorObjectEntry * entry, guint timestamp);
+void    indicator_object_entry_activate_window (IndicatorObject * io, IndicatorObjectEntry * entry, guint windowid, guint timestamp);
 void    indicator_object_entry_close (IndicatorObject * io, IndicatorObjectEntry * entry, guint timestamp);
+gint    indicator_object_get_position (IndicatorObject *io);
 
-void    indicator_object_set_environment (IndicatorObject * io, const GStrv env);
-const GStrv indicator_object_get_environment (IndicatorObject * io);
+void    indicator_object_set_environment (IndicatorObject * io, GStrv env);
+GStrv   indicator_object_get_environment (IndicatorObject * io);
 gboolean indicator_object_check_environment (IndicatorObject * io, const gchar * env);
 
 G_END_DECLS
